const { PrismaClient } = require("@prisma/client");
const prisma = new PrismaClient();

async function createTags(req, res) {
  const { name, blogIDs, blogs } = req.body;
  try {
    const newTag = await prisma.Tag.create({
      data: {
        name,
        blogIDs,
        blogs,
      },
    });
    res.status(201).json(newTag);
  } catch (error) {
    console.error("Error creating comment:", error);
    res.status(500).json({ message: "Error creating blog" });
  }
}
async function getTags(req, res) {
  try {
    const Tags = await prisma.Tag.findMany();
    res.json(Tags);
  } catch (error) {
    console.error("Error getting blogs:", error);
    res
      .status(500)
      .json({ message: "Error getting blogs", error: error.message });
  }
}

async function updateTags(req, res) {
  const { name, blog, blogIDs } = req.body;
  const id = req.params.id;
  try {
    const Tags = await prisma.Tag.findUnique({
      where: { id },
    });
    if (!Tags) {
      return res.status(404).send({
        message: "Comment not found",
      });
    }
    const updatedTags = await prisma.Tag.update({
      where: { id },
      data: {
        name,
        blog,
        blogIDs,
      },
    });

    res.status(200).send(updatedTags);
  } catch (error) {
    console.error("Error updating Tag:", error);
    res.status(500).send({
      message: "Error updating Tag",
      error: error.message,
    });
  }
}

async function deleteTags(req, res) {
  const { id } = req.params;
  try {
    const delTag = await prisma.Tag.delete({
      where: { id },
    });
    res.json(delTag);
  } catch (error) {
    console.error("Error getting blogs:", error);
    res
      .status(500)
      .json({ message: "Error getting blogs", error: error.message });
  }
}
module.exports = {
  createTags,
  getTags,
  updateTags,
  deleteTags,
};
